from abc import abstractmethod

import psycopg2


class BaseMigrater:
    options = None
    db_connection = None

    def __init__(self, options: dict):
        self.options = options
        self.connect_db()

    def __del__(self):
        if self.db_connection is not None:
            self.db_connection.close()

    def connect_db(self):
        if self.options is None:
            return
        conn = psycopg2.connect(
            host=self.options["host"],
            database="ksp",
            user=self.options["db_user"],
            password=self.options["db_pw"],
        )
        print("Connected to ksp db...")
        self.db_connection = conn

    @abstractmethod
    def migrate(self):
        raise NotImplementedError("Must be implemented in subclass")
